"use client";

import { useState, useEffect } from "react";
import BottomNav from "@/components/BottomNav";
import HomeTab from "@/components/HomeTab";
import StatsTab from "@/components/StatsTab";

interface Transaction {
  id: string;
  amount: number;
  type: "INCOME" | "EXPENSE";
  category: string;
  title: string;
  date: Date;
  isRecurring: boolean;
  recurringPeriod?: "weekly" | "monthly" | "yearly";
  createdAt: Date;
  updatedAt: Date;
  syncStatus: "synced" | "pending" | "error";
}

export default function Home() {
  const [activeTab, setActiveTab] = useState("home");
  const [balance, setBalance] = useState(0);
  const [transactions, setTransactions] = useState<Transaction[]>([]);

  useEffect(() => {
    // Aquí cargarías las transacciones desde tu base de datos
    // Por ahora usamos datos de prueba
    const mockTransactions: Transaction[] = [
      {
        id: "1",
        amount: 5000,
        type: "INCOME",
        category: "Salario",
        title: "Salario mensual",
        date: new Date(),
        isRecurring: true,
        recurringPeriod: "monthly",
        createdAt: new Date(),
        updatedAt: new Date(),
        syncStatus: "synced",
      },
      {
        id: "2",
        amount: 1500,
        type: "EXPENSE",
        category: "Alquiler",
        title: "Alquiler mensual",
        date: new Date(),
        isRecurring: true,
        recurringPeriod: "monthly",
        createdAt: new Date(),
        updatedAt: new Date(),
        syncStatus: "synced",
      },
      {
        id: "3",
        amount: 200,
        type: "EXPENSE",
        category: "Compras",
        title: "Supermercado",
        date: new Date(),
        isRecurring: false,
        createdAt: new Date(),
        updatedAt: new Date(),
        syncStatus: "synced",
      },
      {
        id: "4",
        amount: 300,
        type: "INCOME",
        category: "Freelance",
        title: "Trabajo freelance",
        date: new Date(),
        isRecurring: false,
        createdAt: new Date(),
        updatedAt: new Date(),
        syncStatus: "synced",
      },
    ];

    setTransactions(mockTransactions);
    const totalIncome = mockTransactions
      .filter((t) => t.type === "INCOME")
      .reduce((acc, t) => acc + t.amount, 0);
    const totalExpenses = mockTransactions
      .filter((t) => t.type === "EXPENSE")
      .reduce((acc, t) => acc + t.amount, 0);
    setBalance(totalIncome - totalExpenses);
  }, []);

  const handleAddTransaction = () => {
    // Aquí implementarías la lógica para agregar una nueva transacción
    console.log("Agregar nueva transacción");
  };

  return (
    <main className="min-h-screen bg-gray-900 text-white pb-16">
      <div className="container mx-auto px-4 py-8">
        {activeTab === "home" && (
          <HomeTab
            balance={balance}
            transactions={transactions}
            onAddTransaction={handleAddTransaction}
          />
        )}
        {activeTab === "stats" && <StatsTab transactions={transactions} />}
      </div>
      <BottomNav activeTab={activeTab} onTabChange={setActiveTab} />
    </main>
  );
}
